@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013-2014 Aurimas Cernius
+ * Copyright (C) 2013-2016 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <string>
 #include <map>
 
+#include <glibmm/keyfile.h>
 #include <glibmm/ustring.h>
 
 
@@ -84,10 +85,18 @@ public:
     {
       m_addin_module = module;
     }
-  const std::map<Glib::ustring, Glib::ustring> & attributes()
+  const std::map<Glib::ustring, Glib::ustring> & attributes() const
     {
       return m_attributes;
     }
+  const std::map<Glib::ustring, const Glib::VariantType*> & actions() const
+    {
+      return m_actions;
+    }
+  const std::vector<Glib::ustring> & non_modifying_actions() const
+    {
+      return m_non_modifying_actions;
+    }
   Glib::ustring get_attribute(const Glib::ustring & att);
   bool validate(const Glib::ustring & release, const Glib::ustring & version_info) const;
 private:
@@ -104,8 +113,11 @@ private:
   Glib::ustring m_libgnote_version_info;
 
   std::map<Glib::ustring, Glib::ustring> m_attributes;
+  std::map<Glib::ustring, const Glib::VariantType*> m_actions;
+  std::vector<Glib::ustring> m_non_modifying_actions;
 
   bool validate_compatibility(const Glib::ustring & release, const Glib::ustring & version_info) const;
+  void load_actions(Glib::KeyFile & addin_info, const Glib::ustring & key, const Glib::VariantType *type);
 };
 
 }
