@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2015 Aurimas Cernius
+ * Copyright (C) 2013,2015-2016 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -120,10 +120,12 @@ bool MainWindow::use_client_side_decorations()
       sharp::string_split(desktops, setting, ",");
       const char *current_desktop = std::getenv("DESKTOP_SESSION");
       if (current_desktop) {
+        Glib::ustring current_de = Glib::ustring(current_desktop).lowercase();
         FOREACH(std::string de, desktops) {
-	  if(de == current_desktop) {
-	    s_use_client_side_decorations = 1;
-	  }
+          Glib::ustring denv = Glib::ustring(de).lowercase();
+          if(current_de.find(denv) != Glib::ustring::npos) {
+            s_use_client_side_decorations = 1;
+          }
         }
       }
     }
@@ -134,9 +136,9 @@ bool MainWindow::use_client_side_decorations()
 
 
 MainWindow::MainWindow(const std::string & title)
-  : utils::ForcedPresentWindow(title)
-  , m_close_on_esc(false)
+  : m_close_on_esc(false)
 {
+  set_title(title);
 }
 
 }
