@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013 Aurimas Cernius
+ * Copyright (C) 2013,2015-2016 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,8 @@
 
 #include <gtkmm/widget.h>
 
+#include "mainwindowaction.hpp"
+
 
 namespace gnote {
 
@@ -38,6 +40,8 @@ public:
   virtual bool running() = 0;
   virtual bool contains(EmbeddableWidget &) = 0;
   virtual bool is_foreground(EmbeddableWidget &) = 0;
+  virtual MainWindowAction::Ptr find_action(const Glib::ustring & name) = 0;
+  virtual void enabled(bool is_enabled) = 0;
 };
 
 class EmbeddableWidget
@@ -87,8 +91,10 @@ public:
 class HasActions
 {
 public:
-  virtual std::vector<Glib::RefPtr<Gtk::Action> > get_widget_actions() = 0;
-  virtual sigc::signal<void> & signal_actions_changed() = 0;
+  virtual std::vector<Gtk::Widget*> get_popover_widgets() = 0;
+  virtual std::vector<MainWindowAction::Ptr> get_widget_actions() = 0;
+
+  sigc::signal<void> signal_popover_widgets_changed;
 };
 
 }
