@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013 Aurimas Cernius
+ * Copyright (C) 2011,2013,2016 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -51,12 +51,17 @@ protected:
                                      guint info,  guint time) override;
 
 private:
+  static void paste_started(GtkTextView*, NoteEditor *_this);
+  static void paste_ended(GtkTextView*, NoteEditor *_this);
+
   Pango::FontDescription get_gnome_document_font_description();
   void on_font_setting_changed (const Glib::ustring & key);
   void update_custom_font_setting();
   void modify_font_from_string (const std::string & fontString);
   bool key_pressed (GdkEventKey * ev);
   bool button_pressed (GdkEventButton * ev);
+  void on_paste_start();
+  void on_paste_end();
 };
 
 
