@@ -51,6 +51,7 @@ public:
   virtual void new_note() override;
   virtual void present_search() override;
   virtual void close_window() override;
+  virtual bool is_search() override;
 
   virtual void embed_widget(EmbeddableWidget &) override;
   virtual void unembed_widget(EmbeddableWidget &) override;
@@ -77,6 +78,7 @@ private:
   EmbeddableWidget *currently_embedded();
   void make_header_bar();
   void make_search_box();
+  bool on_entry_key_pressed(GdkEventKey *);
   void on_entry_changed();
   void on_entry_activated();
   void entry_changed_timeout();
