@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014 Aurimas Cernius
+ * Copyright (C) 2010-2015 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -54,8 +54,8 @@ public:
   virtual void hint_size(int & width, int & height) override;
   virtual void size_internals() override;
   virtual void perform_search(const std::string & search_text) override;
-  virtual std::vector<Glib::RefPtr<Gtk::Action> > get_widget_actions() override;
-  virtual sigc::signal<void> & signal_actions_changed() override;
+  virtual std::vector<Gtk::Widget*> get_popover_widgets() override;
+  virtual std::vector<MainWindowAction::Ptr> get_widget_actions() override;
 
   void select_all_notes_notebook();
   void new_note();
@@ -129,6 +129,9 @@ private:
   void on_sorting_changed();
   void parse_sorting_setting(const Glib::ustring & sorting);
   void on_rename_notebook();
+  void callbacks_changed();
+  void register_callbacks();
+  void unregister_callbacks();
 
   class RecentSearchColumnTypes
     : public Gtk::TreeModelColumnRecord
@@ -183,6 +186,8 @@ private:
   std::string m_search_text;
   int m_sort_column_id;
   Gtk::SortType m_sort_column_order;
+  std::vector<sigc::connection> m_action_cids;
+  sigc::connection m_callback_changed_cid;
 
   static Glib::RefPtr<Gdk::Pixbuf> get_note_icon();
 };
