@@ -32,7 +32,7 @@ namespace sync {
     : public SyncClient
   {
   public:
-    GnoteSyncClient(NoteManager &);
+    static SyncClient::Ptr create(NoteManagerBase &);
 
     virtual sharp::DateTime last_sync_date() override
       {
@@ -44,8 +44,8 @@ namespace sync {
         return m_last_sync_rev;
       }
     virtual void last_synchronized_revision(int) override;
-    virtual int get_revision(const Note::Ptr & note) override;
-    virtual void set_revision(const Note::Ptr & note, int revision) override;
+    virtual int get_revision(const NoteBase::Ptr & note) override;
+    virtual void set_revision(const NoteBase::Ptr & note, int revision) override;
     virtual std::map<std::string, std::string> deleted_note_titles() override
       {
         return m_deleted_notes;
@@ -56,13 +56,18 @@ namespace sync {
         return m_server_id;
       }
     virtual void associated_server_id(const std::string &) override;
+  protected:
+    GnoteSyncClient();
+    void init(NoteManagerBase &);
+    void parse(const std::string & manifest_path);
+
+    std::string m_local_manifest_file_path;
   private:
     static const char *LOCAL_MANIFEST_FILE_NAME;
 
     void note_deleted_handler(const NoteBase::Ptr &);
     void on_changed(const Glib::RefPtr<Gio::File>&, const Glib::RefPtr<Gio::File>&,
                     Gio::FileMonitorEvent);
-    void parse(const std::string & manifest_path);
     void write(const std::string & manifest_path);
     void read_updated_note_atts(sharp::XmlReader & reader);
     void read_deleted_note_atts(sharp::XmlReader & reader);
@@ -72,7 +77,6 @@ namespace sync {
     sharp::DateTime m_last_sync_date;
     int m_last_sync_rev;
     std::string m_server_id;
-    std::string m_local_manifest_file_path;
     std::map<std::string, int> m_file_revisions;
     std::map<std::string, std::string> m_deleted_notes;
   };
